@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The Mesh TensorFlow Authors.
+# Copyright 2022 The Mesh TensorFlow Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Run masked LM/next sentence masked_lm pre-training for BERT."""
 
 from __future__ import absolute_import
@@ -28,6 +27,7 @@ import mesh_tensorflow.bert.bert as bert_lib
 import mesh_tensorflow.bert.optimization as optimization_lib
 from six.moves import range
 import tensorflow.compat.v1 as tf
+from tensorflow.compat.v1 import estimator as tf_estimator
 
 flags = tf.flags
 
@@ -202,7 +202,7 @@ def model_fn_builder(bert_config, init_checkpoint, learning_rate,
     mtf_next_sentence_labels = mtf.import_tf_tensor(
         mesh, next_sentence_labels, [batch_dim])
 
-    is_training = (mode == tf.estimator.ModeKeys.TRAIN)
+    is_training = (mode == tf_estimator.ModeKeys.TRAIN)
 
     model = bert_lib.BertModel(
         config=bert_config,
@@ -231,7 +231,7 @@ def model_fn_builder(bert_config, init_checkpoint, learning_rate,
     next_sentence_logits = mtf.anonymize(next_sentence_logits)
 
     # TRAIN mode
-    if mode == tf.estimator.ModeKeys.TRAIN:
+    if mode == tf_estimator.ModeKeys.TRAIN:
       _, update_ops = optimization_lib.create_optimizer(
           total_loss + extra_loss,
           learning_rate,
@@ -244,13 +244,13 @@ def model_fn_builder(bert_config, init_checkpoint, learning_rate,
 
     tf_loss = tf.to_float(lowering.export_to_tf_tensor(total_loss))
 
-    if mode == tf.estimator.ModeKeys.TRAIN:
+    if mode == tf_estimator.ModeKeys.TRAIN:
       global_step = tf.train.get_global_step()
       tf_update_ops = [lowering.lowered_operation(op) for op in update_ops]
       tf_update_ops.append(tf.assign_add(global_step, 1))
       tf.logging.info("tf_update_ops: {}".format(tf_update_ops))
       train_op = tf.group(tf_update_ops)
-    elif mode == tf.estimator.ModeKeys.EVAL:
+    elif mode == tf_estimator.ModeKeys.EVAL:
 
       def metric_fn(masked_lm_example_loss, masked_lm_logits, masked_lm_ids,
                     masked_lm_weights, next_sentence_example_loss,
@@ -299,7 +299,7 @@ def model_fn_builder(bert_config, init_checkpoint, learning_rate,
     with mtf.utils.outside_all_rewrites():
       # Copy master variables to slices. Must be called first.
       restore_hook = mtf.MtfRestoreHook(lowering)
-      if mode == tf.estimator.ModeKeys.TRAIN:
+      if mode == tf_estimator.ModeKeys.TRAIN:
         saver = tf.train.Saver(
             tf.global_variables(),
             sharded=True,
@@ -315,14 +315,14 @@ def model_fn_builder(bert_config, init_checkpoint, learning_rate,
             saver=saver,
             listeners=[saver_listener])
 
-        return tf.estimator.tpu.TPUEstimatorSpec(
-            tf.estimator.ModeKeys.TRAIN,
+        return tf_estimator.tpu.TPUEstimatorSpec(
+            tf_estimator.ModeKeys.TRAIN,
             loss=tf_loss,
             train_op=train_op,
             training_hooks=[restore_hook, saver_hook])
-      elif mode == tf.estimator.ModeKeys.EVAL:
-        return tf.estimator.tpu.TPUEstimatorSpec(
-            tf.estimator.ModeKeys.EVAL,
+      elif mode == tf_estimator.ModeKeys.EVAL:
+        return tf_estimator.tpu.TPUEstimatorSpec(
+            tf_estimator.ModeKeys.EVAL,
             evaluation_hooks=[restore_hook],
             loss=tf_loss,
             eval_metrics=eval_metrics)
@@ -440,15 +440,15 @@ def main(_):
     tpu_cluster_resolver = tf.distribute.cluster_resolver.TPUClusterResolver(
         FLAGS.tpu_name, zone=FLAGS.tpu_zone, project=FLAGS.gcp_project)
 
-  run_config = tf.estimator.tpu.RunConfig(
+  run_config = tf_estimator.tpu.RunConfig(
       cluster=tpu_cluster_resolver,
       master=FLAGS.master,
       model_dir=FLAGS.output_dir,
       save_checkpoints_steps=FLAGS.save_checkpoints_steps,
-      tpu_config=tf.estimator.tpu.TPUConfig(
+      tpu_config=tf_estimator.tpu.TPUConfig(
           iterations_per_loop=FLAGS.iterations_per_loop,
           num_cores_per_replica=1,
-          per_host_input_for_training=tf.estimator.tpu.InputPipelineConfig
+          per_host_input_for_training=tf_estimator.tpu.InputPipelineConfig
           .BROADCAST))
 
   model_fn = model_fn_builder(
@@ -460,7 +460,7 @@ def main(_):
 
   # If TPU is not available, this will fall back to normal Estimator on CPU
   # or GPU.
-  estimator = tf.estimator.tpu.TPUEstimator(
+  estimator = tf_estimator.tpu.TPUEstimator(
       use_tpu=FLAGS.use_tpu,
       model_fn=model_fn,
       config=run_config,
