@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The Mesh TensorFlow Authors.
+# Copyright 2022 The Mesh TensorFlow Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,6 +29,7 @@ import six
 from six.moves import range
 from six.moves import zip
 import tensorflow.compat.v1 as tf
+from tensorflow.compat.v1 import estimator as tf_estimator
 
 # pylint: disable=g-direct-tensorflow-import
 # pylint: disable=g-direct-third-party-import
@@ -99,7 +100,7 @@ class _CapturedObject(object):
     return self._object
 
 
-class _CkptLoaderHook(tf.estimator.SessionRunHook):
+class _CkptLoaderHook(tf_estimator.SessionRunHook):
   """Load checkpoint right after the session started."""
 
   def after_create_session(self, session, coord):
