@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The Mesh TensorFlow Authors.
+# Copyright 2022 The Mesh TensorFlow Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@ from __future__ import print_function
 
 import contextlib
 
+# pylint: disable=g-direct-tensorflow-import
 from tensorflow.python.framework import ops
 from tensorflow.python.ops import control_flow_ops
 from tensorflow.python.ops import gen_resource_variable_ops
@@ -81,7 +82,9 @@ class ReplicatedVariable(VariableBase):
     if tpu_context is None:
       return self._primary_var.handle
 
-    return tpu_context.get_replicated_var_handle(self._name, self._vars)
+    # Using variable name as handle id.
+    return tpu_context.get_replicated_var_handle(self._name, self._name,
+                                                 self._vars)
 
   @contextlib.contextmanager
   def _assign_dependencies(self):
